@@ -18,11 +18,11 @@ import signal
 import uuid
 
 from neutron.agent.linux import utils
-from neutron.common import constants as n_const
 from neutron.services.logapi.agent import log_extension as log_ext
-from neutron.services.logapi.common import constants as log_const
 from neutron_lib import constants
+from neutron_lib.services.logapi import constants as log_const
 from oslo_config import cfg
+from oslo_log import formatters
 from oslo_log import handlers
 from oslo_log import log as logging
 
@@ -47,12 +47,15 @@ def setup_logging():
 
     log_file = cfg.CONF.network_log.local_output_log_base
     if log_file:
-        import logging
-        log_file_handler = logging.handlers.WatchedFileHandler(log_file)
-        log_file_handler.setLevel(logging.INFO)
-        log_file_handler.setFormatter(logging.Formatter(
-            fmt="%(asctime)s %(message)s", datefmt=cfg.CONF.log_date_format))
+        from logging import handlers as watch_handler
+        log_file_handler = watch_handler.WatchedFileHandler(log_file)
+        log_file_handler.setLevel(
+            logging.DEBUG if cfg.CONF.debug else logging.INFO)
         LOG.logger.addHandler(log_file_handler)
+        log_file_handler.setFormatter(
+            formatters.ContextFormatter(
+                fmt=cfg.CONF.logging_default_format_string,
+                datefmt=cfg.CONF.log_date_format))
     elif cfg.CONF.use_journal:
         journal_handler = handlers.OSJournalHandler()
         LOG.logger.addHandler(journal_handler)
@@ -370,7 +373,7 @@ class IptablesLoggingDriver(log_ext.LoggingDriver):
         agent_mode = self.conf.agent_mode
         router = self.agent_api.get_router_hosting_port(port_id)
         if_prefix = self._get_if_prefix(agent_mode, router)
-        return (if_prefix + port_id)[:n_const.LINUX_DEV_LEN]
+        return (if_prefix + port_id)[:constants.LINUX_DEV_LEN]
 
     def _get_ipt_mgr_by_port(self, port_id):
 
@@ -502,12 +505,15 @@ class IptablesLoggingDriver(log_ext.LoggingDriver):
                   (IPTABLES_DIRECTION_DEVICE[direction], device)]
         match_rule = []
         if self.rate_limit:
-            match_rule += ['-m', 'limit', '--limit', '%s/s' % self.rate_limit]
+            match_rule += [
+                '-m', 'limit', '--limit', '%s/sec' % self.rate_limit]
             if self.burst_limit:
                 match_rule += ['--limit-burst %s' % self.burst_limit]
         target = ['-j', 'NFLOG']
         if prefix:
-            target += ['--nflog-prefix', '%s' % prefix]
+            # NOTE: There is an extra space after 'nflog-prefix' in
+            # iptables-save output, account for it here.
+            target += ['--nflog-prefix ', '%s' % prefix]
 
         args = direction_config + match_rule + target
         return args
